pitchtools.PitchRange
=====================

.. abjad-lineage:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange

.. autoclass:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.one_line_named_chromatic_pitch_repr
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.one_line_numbered_chromatic_pitch_repr
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.pitch_range_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.pitch_range_name_markup
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.start_pitch
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.start_pitch_is_included_in_range
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.stop_pitch
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.stop_pitch_is_included_in_range
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.PitchRange.__repr__
   :noindex:
